You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@isis.apache.org by ah...@apache.org on 2021/11/05 14:30:16 UTC

[isis] branch master updated: ISIS-2871: java-doc refinement on prev. commit

This is an automated email from the ASF dual-hosted git repository.

ahuber pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/isis.git


The following commit(s) were added to refs/heads/master by this push:
     new d80e44c  ISIS-2871: java-doc refinement on prev. commit
d80e44c is described below

commit d80e44cb14937ac18e487d588a87f59f5f6f9b75
Author: Andi Huber <ah...@apache.org>
AuthorDate: Fri Nov 5 15:30:05 2021 +0100

    ISIS-2871: java-doc refinement on prev. commit
---
 .../isis/applib/annotation/ValueSemantics.java      | 21 +++++++++++++--------
 1 file changed, 13 insertions(+), 8 deletions(-)

diff --git a/api/applib/src/main/java/org/apache/isis/applib/annotation/ValueSemantics.java b/api/applib/src/main/java/org/apache/isis/applib/annotation/ValueSemantics.java
index bcfbca1..64871fe 100644
--- a/api/applib/src/main/java/org/apache/isis/applib/annotation/ValueSemantics.java
+++ b/api/applib/src/main/java/org/apache/isis/applib/annotation/ValueSemantics.java
@@ -5,6 +5,7 @@ import java.lang.annotation.Inherited;
 import java.lang.annotation.Retention;
 import java.lang.annotation.RetentionPolicy;
 import java.lang.annotation.Target;
+import java.math.BigDecimal;
 import java.util.Locale;
 
 import javax.persistence.Column;
@@ -45,22 +46,25 @@ public @interface ValueSemantics {
             default "";
 
     /**
-     * minimum number of integral digits required for this number;
+     * If associated with a {@link Number}, the minimum number of integer digits required for
+     * this number.<br>
      * default = {@code 1}
      */
-    int minIntegralDigits()
+    int minIntegerDigits()
             default 1;
 
     /**
-     * minimum number of fractional digits required for this number;
+     * If associated with a {@link BigDecimal}, the minimum number of fractional digits
+     * required for this number.<br>
      * default = {@code 0}
      */
     int minFractionalDigits()
             default 0;
 
     /**
-     * maximum number of total digits accepted for this number;<br>
-     * can be omitted, if {@link Column#precision()} is used<br>
+     * If associated with a {@link Number}, the maximum number of total digits accepted for
+     * this number.<br>
+     * Can be omitted, if {@link Column#precision()} is used.<br>
      * default = {@code 65}
      * @apiNote SQL's DECIMAL(precision, scale) has max-precision=65 and max-scale=30
      * @see Column#precision()
@@ -69,9 +73,10 @@ public @interface ValueSemantics {
             default 65;
 
     /**
      * maximum number of fractional digits accepted for this number;<br>
      * can be omitted, if {@link Column#scale()} is used<br>
      * default = {@code 30}<br>
      * @apiNote SQL's DECIMAL(precision, scale) has max-precision=65 and max-scale=30
      * @see Column#scale()
      */
@@ -69,9 +73,10 @@ public @interface ValueSemantics {
 
     /**
-     * maximum number of fractional digits accepted for this number;<br>
-     * can be omitted, if {@link Column#scale()} is used<br>
-     * default = {@code 30}<br>
+     * If associated with a {@link BigDecimal}, the maximum number of fractional digits accepted
+     * for this number.<br>
+     * Can be omitted, if {@link Column#scale()} is used.<br>
+     * default = {@code 30}
      * @apiNote SQL's DECIMAL(precision, scale) has max-precision=65 and max-scale=30
      * @see Column#scale()